@@ -82,9 +82,8 @@ static void addDataStrings(KAboutData &aboutdata)
     aboutdata.addAuthor(
         i18n("Mark Penner"),
         QString(),
-        u"mrp@markpenner.space"_s,
-        u"https://markpenner.space"_s
-    );
+        _("mrp@markpenner.space"),
+        i18n("https://markpenner.space"));
 
     // people who helped
     aboutdata.addCredit(
@@ -149,11 +148,6 @@ static void addDataStrings(KAboutData &aboutdata)
         QString());
 }
 
-#ifdef WITH_OPTIMIZED_MEMCPY
-/* forward declaration to libkwave/memcpy.c */
-extern "C" void probe_fast_memcpy(void);
-#endif /* WITH_OPTIMIZED_MEMCPY */
-
 //***************************************************************************
 int main(int argc, char **argv)
 {
@@ -215,6 +209,8 @@ int main(int argc, char **argv)
 
     KCrash::initialize();
 
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kwave")));
+
     /* show some version info */
     qDebug("\nThis is %s v%s (compiled with KDE Frameworks %s)\n",
         about.productName().toLatin1().data(),
@@ -232,12 +228,6 @@ int main(int argc, char **argv)
     /* let Kwave be a "unique" application, only one instance */
     KDBusService service(KDBusService::Unique);
 
-     /* check for an optimized version of memcpy() */
-#ifdef WITH_OPTIMIZED_MEMCPY
-    probe_fast_memcpy();
-    qDebug("\n");
-#endif /* WITH_OPTIMIZED_MEMCPY */
-
     // check whether to start up without splash screen or in iconic mode
     // which implicitly also disables the splash screen
     Kwave::Splash splash(_("pics/kwave-splash.png"));
