@@ -15,7 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
 
 #include <QHash>
 #include <QObject>
@@ -33,8 +32,7 @@ Kwave::MenuGroup::MenuGroup(Kwave::MenuNode *parent,
      m_name(name),
      m_members(),
      m_action_group((mode == EXCLUSIVE) ?
-        new(std::nothrow) QActionGroup(parent) : Q_NULLPTR),
-     m_enabled(true)
+        new(std::nothrow) QActionGroup(parent) : nullptr)
 {
     Q_ASSERT(parent);
     Q_ASSERT(m_name.length());
@@ -90,10 +88,10 @@ void Kwave::MenuGroup::setEnabled(bool enable)
 //*****************************************************************************
 void Kwave::MenuGroup::selectItem(const QString &uid)
 {
-    Kwave::MenuNode *new_selection = Q_NULLPTR;
+    Kwave::MenuNode *new_selection = nullptr;
 
     foreach (Kwave::MenuNode *member, m_members) {
-        if (member == Q_NULLPTR) continue;
+        if (member == nullptr) continue;
         if (uid == member->uid())
             new_selection = member;    // new selected member found !
         else
