@@ -34,6 +34,15 @@ Kwave::SampleFIFO::SampleFIFO(const Kwave::SampleFIFO &other)
 {
 }
 
+//***************************************************************************
+Kwave::SampleFIFO& Kwave::SampleFIFO::operator=(const Kwave::SampleFIFO &other)
+{
+    m_buffer      = other.m_buffer;
+    m_size        = other.m_size;
+    m_read_offset = other.m_read_offset;
+    return *this;
+}
+
 //***************************************************************************
 Kwave::SampleFIFO::~SampleFIFO()
 {
