@@ -83,12 +83,6 @@ Kwave::WorkerThread::~WorkerThread()
     Q_ASSERT(!isRunning());
 }
 
-//***************************************************************************
-void Kwave::WorkerThread::start()
-{
-    QThread::start();
-}
-
 //***************************************************************************
 void Kwave::WorkerThread::cancel()
 {
