@@ -92,7 +92,7 @@ bool Kwave::UndoDeleteAction::store(Kwave::SignalManager &manager)
 Kwave::UndoAction *Kwave::UndoDeleteAction::undo(Kwave::SignalManager &manager,
                                                  bool with_redo)
 {
-    Kwave::UndoAction *redo_action = Q_NULLPTR;
+    Kwave::UndoAction *redo_action = nullptr;
 
     // store data for redo
     if (with_redo) {
@@ -101,7 +101,7 @@ Kwave::UndoAction *Kwave::UndoDeleteAction::undo(Kwave::SignalManager &manager,
             m_offset, m_length
         );
         Q_ASSERT(redo_action);
-        if (!redo_action) return Q_NULLPTR;
+        if (!redo_action) return nullptr;
         redo_action->store(manager);
     }
 
@@ -111,14 +111,14 @@ Kwave::UndoAction *Kwave::UndoDeleteAction::undo(Kwave::SignalManager &manager,
     if (!manager.insertSpace(m_offset, m_length, m_track_list)) {
         qWarning("UndoDeleteAction::undo() FAILED [insertSpace]");
         delete redo_action;
-        return Q_NULLPTR;
+        return nullptr;
     }
 
     // merge the stripes back into the signal
     if (!manager.mergeStripes(m_stripes, m_track_list)) {
         qWarning("UndoDeleteAction::undo() FAILED [mergeStripes]");
         delete redo_action;
-        return Q_NULLPTR;
+        return nullptr;
     }
 
     // restore the saved meta data
