@@ -26,8 +26,6 @@
 
 #include "ui_AmplifyFreeDlg.h"
 
-class QStringList;
-
 namespace Kwave
 {
     class AmplifyFreeDialog: public QDialog, public Ui::AmplifyFreeDlg
@@ -39,7 +37,7 @@ namespace Kwave
         explicit AmplifyFreeDialog(QWidget *parent);
 
         /** Destructor */
-        virtual ~AmplifyFreeDialog();
+        ~AmplifyFreeDialog() override;
 
         /** Returns a command string for the curve */
         QString getCommand();
