@@ -61,7 +61,7 @@ namespace Kwave
                     ogg_packet &op);
 
         /** destructor */
-        virtual ~OpusDecoder() Q_DECL_OVERRIDE {}
+        ~OpusDecoder() override {}
 
         /**
          * parse the header of the stream and initialize the decoder
@@ -70,23 +70,23 @@ namespace Kwave
          * @return -1 if failed or +1 if succeeded
          */
         virtual int open(QWidget *widget, Kwave::FileInfo &info)
-            Q_DECL_OVERRIDE;
+            override;
 
         /**
          * decode received ogg data
          * @param dst a MultiWriter to be used as sink
          * @return -1 if failed or >= 0 if succeeded
          */
-        virtual int decode(Kwave::MultiWriter &dst) Q_DECL_OVERRIDE;
+        int decode(Kwave::MultiWriter &dst) override;
 
         /** reset the stream info */
-        virtual void reset() Q_DECL_OVERRIDE;
+        void reset() override;
 
         /**
          * finish the decoding, last chance to fix up some file info
          * @param info reference to a FileInfo to fill
          */
-        virtual void close(Kwave::FileInfo &info) Q_DECL_OVERRIDE;
+        void close(Kwave::FileInfo &info) override;
 
     protected:
 
