@@ -41,10 +41,10 @@ namespace Kwave
         WavEncoder();
 
         /** Destructor */
-        virtual ~WavEncoder() Q_DECL_OVERRIDE;
+        ~WavEncoder() override;
 
         /** Returns a new instance of the encoder */
-        virtual Encoder *instance() Q_DECL_OVERRIDE;
+        Encoder *instance() override;
 
         /**
          * Encodes a signal into a stream of bytes.
@@ -58,11 +58,11 @@ namespace Kwave
         virtual bool encode(QWidget *widget, Kwave::MultiTrackReader &src,
                             QIODevice &dst,
                             const Kwave::MetaDataList &meta_data)
-            Q_DECL_OVERRIDE;
+            override;
 
         /** Returns a list of supported file properties */
         virtual QList<Kwave::FileProperty> supportedProperties()
-            Q_DECL_OVERRIDE;
+            override;
 
     private:
 
